@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn15.h,v 1.11 2005/11/10 22:19:07 joerg_wunsch Exp $ */
+/* $Id: iotn15.h,v 1.12.2.2 2008/01/06 20:10:46 arcanum Exp $ */
 
 /* avr/iotn15.h - definitions for ATtiny15 */
 
@@ -304,4 +304,23 @@
 #define E2END		0x3F
 #define FLASHEND	0x3FF
 
+
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 1
+
+/* Fuse Byte */
+#define FUSE_CKSEL0      ~_BV(0)
+#define FUSE_CKSEL1      ~_BV(1)
+#define FUSE_RSTDISBL    ~_BV(4)
+#define FUSE_SPIEN       ~_BV(5)
+#define FUSE_BODEN       ~_BV(6)
+#define FUSE_BODLEVEL    ~_BV(7)
+#define FUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL1 & FUSE_SPIEN)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+
+
 #endif /* _AVR_IOTN15_H_ */
