@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iousbxx6_7.h,v 1.1.2.2 2006/06/24 12:01:03 aesok Exp $ */
+/* $Id: iousbxx6_7.h,v 1.4 2007/05/13 20:43:52 aesok Exp $ */
 
 /* iousbxx6_7.h - definitions for AT90USB646, AT90USB647, AT90USB1286 
    and AT90USB1287 */
@@ -77,14 +77,14 @@
 #define DDA0    0
 
 #define PORTA   _SFR_IO8(0X02)
-#define PORTA7  7
-#define PORTA6  6
-#define PORTA5  5
-#define PORTA4  4
-#define PORTA3  3
-#define PORTA2  2
-#define PORTA1  1
-#define PORTA0  0
+#define PA7  7
+#define PA6  6
+#define PA5  5
+#define PA4  4
+#define PA3  3
+#define PA2  2
+#define PA1  1
+#define PA0  0
 
 #define PINB    _SFR_IO8(0X03)
 #define PINB7   7
@@ -107,14 +107,14 @@
 #define DDB0    0
 
 #define PORTB   _SFR_IO8(0x05)
-#define PORTB7  7
-#define PORTB6  6
-#define PORTB5  5
-#define PORTB4  4
-#define PORTB3  3
-#define PORTB2  2
-#define PORTB1  1
-#define PORTB0  0
+#define PB7  7
+#define PB6  6
+#define PB5  5
+#define PB4  4
+#define PB3  3
+#define PB2  2
+#define PB1  1
+#define PB0  0
 
 #define PINC    _SFR_IO8(0x06)
 #define PINC7   7
@@ -137,14 +137,14 @@
 #define DDC0    0
 
 #define PORTC   _SFR_IO8(0x08)
-#define PORTC7  7
-#define PORTC6  6
-#define PORTC5  5
-#define PORTC4  4
-#define PORTC3  3
-#define PORTC2  2
-#define PORTC1  1
-#define PORTC0  0
+#define PC7  7
+#define PC6  6
+#define PC5  5
+#define PC4  4
+#define PC3  3
+#define PC2  2
+#define PC1  1
+#define PC0  0
 
 #define PIND    _SFR_IO8(0x09)
 #define PIND7   7
@@ -167,14 +167,14 @@
 #define DDD0    0
 
 #define PORTD   _SFR_IO8(0x0B)
-#define PORTD7  7
-#define PORTD6  6
-#define PORTD5  5
-#define PORTD4  4
-#define PORTD3  3
-#define PORTD2  2
-#define PORTD1  1
-#define PORTD0  0
+#define PD7  7
+#define PD6  6
+#define PD5  5
+#define PD4  4
+#define PD3  3
+#define PD2  2
+#define PD1  1
+#define PD0  0
 
 #define PINE    _SFR_IO8(0x0C)
 #define PINE7   7
@@ -197,14 +197,14 @@
 #define DDE0    0
 
 #define PORTE   _SFR_IO8(0x0E)
-#define PORTE7  7
-#define PORTE6  6
-#define PORTE5  5
-#define PORTE4  4
-#define PORTE3  3
-#define PORTE2  2
-#define PORTE1  1
-#define PORTE0  0
+#define PE7  7
+#define PE6  6
+#define PE5  5
+#define PE4  4
+#define PE3  3
+#define PE2  2
+#define PE1  1
+#define PE0  0
 
 #define PINF    _SFR_IO8(0x0F)
 #define PINF7   7
@@ -227,14 +227,14 @@
 #define DDF0    0
 
 #define PORTF   _SFR_IO8(0x11)
-#define PORTF7  7
-#define PORTF6  6
-#define PORTF5  5
-#define PORTF4  4
-#define PORTF3  3
-#define PORTF2  2
-#define PORTF1  1
-#define PORTF0  0
+#define PF7  7
+#define PF6  6
+#define PF5  5
+#define PF4  4
+#define PF3  3
+#define PF2  2
+#define PF1  1
+#define PF0  0
 
 /* Reserved [0x12..0x14] */
 
@@ -1264,7 +1264,7 @@
 /* Timer/Counter3 Overflow */
 #define TIMER3_OVF_vect			_VECTOR(35)
 
-/* 2-wire Serial Interface         */
+/* 2-wire Serial Interface */
 #define TWI_vect			_VECTOR(36)
 
 /* Store Program Memory Read */
