@@ -27,7 +27,7 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: puts_p.c,v 1.4 2004/07/21 22:11:59 joerg_wunsch Exp $ */
+/* $Id: puts_p.c,v 1.5 2005/09/06 18:49:15 joerg_wunsch Exp $ */
 
 #include <stdio.h>
 #include <avr/pgmspace.h>
@@ -48,11 +48,11 @@ puts_P(const char *str)
 	 * macro, so it could evaluate its argument more than once.
 	 */
 	while ((c = pgm_read_byte(str)) != '\0') {
-		if (stdout->put(c) != 0)
+		if (stdout->put(c, stdout) != 0)
 			rv = EOF;
 		str++;
 	}
-	if (stdout->put('\n') != 0)
+	if (stdout->put('\n', stdout) != 0)
 		rv = EOF;
 
 	return rv;
