@@ -27,14 +27,12 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: vsnprintf_p.c,v 1.1 2003/11/12 20:50:03 joerg_wunsch Exp $ */
+/* $Id: vsnprintf_p.c,v 1.2 2007/03/17 23:11:58 dmix Exp $ */
 
 #include <limits.h>
 #include <stdarg.h>
 #include <stdio.h>
 
-#include "stdio_private.h"
-
 int
 vsnprintf_P(char *s, size_t n, const char *fmt, va_list ap)
 {
@@ -43,12 +41,21 @@ vsnprintf_P(char *s, size_t n, const char *fmt, va_list ap)
 
 	f.flags = __SWR | __SSTR | __SPGM;
 	f.buf = s;
-	if (n > (size_t)INT_MAX)
-		f.size = INT_MAX;
-	else
-		f.size = (int)n - 1;
+	/* Restrict max output length to 32767, as snprintf() return
+	   signed int. The fputc() function uses a signed comparison
+	   between estimated len and f.size field. So we can write a
+	   negative value into f.size in the case of n was 0. Note,
+	   that f.size will be a max number of nonzero symbols.	*/
+	if ((int)n < 0)
+		n = (unsigned)INT_MAX + 1;		/* 32768 */
+	f.size = n - 1;				/* -1,0,...32767 */
+
 	i = vfprintf(&f, fmt, ap);
-	s[i < f.size? i: f.size] = 0;
+
+	/* We use f.size (not 'n') as this is more effective: two 'ld'
+	   instructions vs. two 'push+pop' and 'movw'.	*/
+	if (f.size >= 0)
+		s[f.len < f.size ? f.len : f.size] = 0;
 
 	return i;
 }
